#!/bin/sh

THIS_DIR=$(realpath $(dirname "$0"))
E2ACCESS_DIR="$HOME"/L4/Filesystems/e2access
E2ACCESS="$E2ACCESS_DIR"/e2access

export LD_LIBRARY_PATH=$E2ACCESS_DIR



# access_image ...

access_image()
{
    "$E2ACCESS" "$TARGET" $*
}

# copy_files <source directory>

copy_files()
{
    access_image --copy-in $(find "$1" -maxdepth 1 -type f | sort) "$1"
}

# make_image <root directory>

make_image()
{
    EXTRA=100
    SIZE=$(du -s -k "$1" | cut -f 1)
    TOTAL=$(($SIZE + $EXTRA))

    dd if=/dev/zero of="$TARGET" bs=1024 count=$TOTAL

    if ! $(/sbin/mkfs.ext2 -q "$TARGET") ; then
        exit 1
    fi
}



# Make several filesystem images.

TARGET="$THIS_DIR"/vfstest_share.fs

mkdir tmp_vfstest_share
cd tmp_vfstest_share
mkdir common-licenses
cp "$THIS_DIR"/resources/GPL-[23] common-licenses

# Create a filesystem image.

make_image common-licenses

# Add the directory and files to the image.

access_image --make-dirs common-licenses
copy_files common-licenses

# Leave the root of the filesystem.

cd ..

access_image --list-dirs '""'
access_image --list-dirs 'common-licenses'

rm -r tmp_vfstest_share



TARGET="$THIS_DIR"/vfstest_etc.fs

mkdir tmp_vfstest_etc
cd tmp_vfstest_etc
mkdir messages
cat > messages/motd <<EOF
Hello! This is the message of the day.

You should be reading this in a file within the /etc filesystem.
EOF

# Create a filesystem image.

make_image messages

# Add the directory and files to the image.

access_image --make-dirs messages
copy_files messages

# Leave the root of the filesystem.

cd ..

access_image --list-dirs '""'
access_image --list-dirs 'messages'

rm -r tmp_vfstest_etc



TARGET="$THIS_DIR"/vfstest_root.fs

mkdir tmp_vfstest_root
cd tmp_vfstest_root
mkdir root
cat > root/reminder <<EOF
Hello! This is just a reminder to have a root filesystem.
EOF

# Create a filesystem image.

make_image root

# Add the directory and files to the image.

access_image --make-dirs root
copy_files root

# Leave the root of the filesystem.

cd ..

access_image --list-dirs '""'
access_image --list-dirs 'root'

rm -r tmp_vfstest_root
